@@ -1,4 +1,4 @@
-from aws_cdk.core import App
+from aws_cdk import App
 
 from b_cfn_lambda_layer_test.integration.infrastructure.main_stack import MainStack
 
